==> gorilla-notes-0.4.0-20200912.222428-2.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$Player.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$Player=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&
obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=void 0;var _react=function(obj){if(obj&&
obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=
obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index"));global=require("module$node_modules$react_player$lib$props");var _utils=require("module$node_modules$react_player$lib$utils");require=function(_Component){function Player$jscomp$0(){if(!(this instanceof Player$jscomp$0))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,_args=Array(_len),_key=0;_key<_len;_key++)_args[_key]=arguments[_key];var _this=
_super.call.apply(_super,[this].concat(_args));_defineProperty(_assertThisInitialized(_this),"mounted",!1);_defineProperty(_assertThisInitialized(_this),"isReady",!1);_defineProperty(_assertThisInitialized(_this),"isPlaying",!1);_defineProperty(_assertThisInitialized(_this),"isLoading",!0);_defineProperty(_assertThisInitialized(_this),"loadOnReady",null);_defineProperty(_assertThisInitialized(_this),"startOnPlay",!0);_defineProperty(_assertThisInitialized(_this),"seekOnPlay",null);_defineProperty(_assertThisInitialized(_this),
"onDurationCalled",!1);_defineProperty(_assertThisInitialized(_this),"getInternalPlayer",function(key){return _this.player?_this.player[key]:null});_defineProperty(_assertThisInitialized(_this),"progress",function(){if(_this.props.url&&_this.player&&_this.isReady){var playedSeconds=_this.getCurrentTime()||0,loadedSeconds=_this.getSecondsLoaded(),duration=_this.getDuration();if(duration){playedSeconds={playedSeconds,played:playedSeconds/duration};null!==loadedSeconds&&(playedSeconds.loadedSeconds=
loadedSeconds,playedSeconds.loaded=loadedSeconds/duration);if(playedSeconds.playedSeconds!==_this.prevPlayed||playedSeconds.loadedSeconds!==_this.prevLoaded)_this.props.onProgress(playedSeconds);_this.prevPlayed=playedSeconds.playedSeconds;_this.prevLoaded=playedSeconds.loadedSeconds}}_this.progressTimeout=setTimeout(_this.progress,_this.props.progressFrequency||_this.props.progressInterval)});_defineProperty(_assertThisInitialized(_this),"handleReady",function(){if(_this.mounted){_this.isReady=!0;
_this.isLoading=!1;var _this$props=_this.props,onReady=_this$props.onReady,playing=_this$props.playing,volume=_this$props.volume;_this$props=_this$props.muted;onReady();_this$props||null===volume||_this.player.setVolume(volume);_this.loadOnReady?(_this.player.load(_this.loadOnReady,!0),_this.loadOnReady=null):playing&&_this.player.play();_this.handleDurationCheck()}});_defineProperty(_assertThisInitialized(_this),"handlePlay",function(){_this.isPlaying=!0;_this.isLoading=!1;var _this$props2=_this.props,
onStart=_this$props2.onStart,onPlay=_this$props2.onPlay;_this$props2=_this$props2.playbackRate;_this.startOnPlay&&(_this.player.setPlaybackRate&&1!==_this$props2&&_this.player.setPlaybackRate(_this$props2),onStart(),_this.startOnPlay=!1);onPlay();_this.seekOnPlay&&(_this.seekTo(_this.seekOnPlay),_this.seekOnPlay=null);_this.handleDurationCheck()});_defineProperty(_assertThisInitialized(_this),"handlePause",function(e){_this.isPlaying=!1;if(!_this.isLoading)_this.props.onPause(e)});_defineProperty(_assertThisInitialized(_this),
"handleEnded",function(){var _this$props3=_this.props,loop=_this$props3.loop,onEnded=_this$props3.onEnded;_this$props3.activePlayer.loopOnEnded&&loop&&_this.seekTo(0);loop||(_this.isPlaying=!1,onEnded())});_defineProperty(_assertThisInitialized(_this),"handleError",function(){var _this$props4;_this.isLoading=!1;(_this$props4=_this.props).onError.apply(_this$props4,arguments)});_defineProperty(_assertThisInitialized(_this),"handleDurationCheck",function(){clearTimeout(_this.durationCheckTimeout);var duration=
_this.getDuration();duration?_this.onDurationCalled||(_this.props.onDuration(duration),_this.onDurationCalled=!0):_this.durationCheckTimeout=setTimeout(_this.handleDurationCheck,100)});_defineProperty(_assertThisInitialized(_this),"handleLoaded",function(){_this.isLoading=!1});_defineProperty(_assertThisInitialized(_this),"ref",function(player){player&&(_this.player=player)});return _this}_inherits(Player$jscomp$0,_Component);var _super=_createSuper(Player$jscomp$0);_createClass(Player$jscomp$0,[{key:"componentDidMount",
value:function(){this.mounted=!0;this.player.load(this.props.url);this.progress()}},{key:"componentWillUnmount",value:function(){clearTimeout(this.progressTimeout);clearTimeout(this.durationCheckTimeout);this.isReady&&this.player.stop();this.player.disablePIP&&this.player.disablePIP();this.mounted=!1}},{key:"componentDidUpdate",value:function(prevProps){var _this2=this,_this$props5=this.props,url=_this$props5.url,playing=_this$props5.playing,volume=_this$props5.volume,muted=_this$props5.muted,playbackRate=
_this$props5.playbackRate,pip=_this$props5.pip,loop=_this$props5.loop;_this$props5=_this$props5.activePlayer;if(!(0,_utils.isEqual)(prevProps.url,url)){if(this.isLoading&&!_this$props5.forceLoad){console.warn("ReactPlayer: the attempt to load ".concat(url," is being deferred until the player has loaded"));this.loadOnReady=url;return}this.startOnPlay=this.isLoading=!0;this.onDurationCalled=!1;this.player.load(url,this.isReady)}prevProps.playing||!playing||this.isPlaying||this.player.play();prevProps.playing&&
!playing&&this.isPlaying&&this.player.pause();!prevProps.pip&&pip&&this.player.enablePIP&&this.player.enablePIP();prevProps.pip&&!pip&&this.player.disablePIP&&this.player.disablePIP();prevProps.volume!==volume&&null!==volume&&this.player.setVolume(volume);prevProps.muted!==muted&&(muted?this.player.mute():(this.player.unmute(),null!==volume&&setTimeout(function(){return _this2.player.setVolume(volume)})));prevProps.playbackRate!==playbackRate&&this.player.setPlaybackRate&&this.player.setPlaybackRate(playbackRate);
prevProps.loop!==loop&&this.player.setLoop&&this.player.setLoop(loop)}},{key:"getDuration",value:function(){return this.isReady?this.player.getDuration():null}},{key:"getCurrentTime",value:function(){return this.isReady?this.player.getCurrentTime():null}},{key:"getSecondsLoaded",value:function(){return this.isReady?this.player.getSecondsLoaded():null}},{key:"seekTo",value:function(amount,type){var _this3=this;this.isReady||0===amount?(type?"fraction"===type:0<amount&&1>amount)?(type=this.player.getDuration())?
this.player.seekTo(type*amount):console.warn("ReactPlayer: could not seek using fraction – duration not yet available"):this.player.seekTo(amount):(this.seekOnPlay=amount,setTimeout(function(){_this3.seekOnPlay=null},5E3))}},{key:"render",value:function(){var Player=this.props.activePlayer;return Player?_react["default"].createElement(Player,_extends({},this.props,{ref:this.ref,onReady:this.handleReady,onPlay:this.handlePlay,onPause:this.handlePause,onEnded:this.handleEnded,onLoaded:this.handleLoaded,
onError:this.handleError})):null}}]);return Player$jscomp$0}(_react.Component);exports["default"]=require;_defineProperty(require,"displayName","Player");_defineProperty(require,"propTypes",global.propTypes);_defineProperty(require,"defaultProps",global.defaultProps)}
//# sourceMappingURL=module$node_modules$react_player$lib$Player.js.map

==> gorilla-notes-0.5.0-20201229.184304-11.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$Player.js <==
shadow$provide.module$node_modules$react_player$lib$Player=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&
obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=void 0;var _react=function(obj){if(obj&&
obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=
obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index"));global=require("module$node_modules$react_player$lib$props");var _utils=require("module$node_modules$react_player$lib$utils");require=function(_Component){function Player$jscomp$0(){if(!(this instanceof Player$jscomp$0))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,_args=Array(_len),_key=0;_key<_len;_key++)_args[_key]=arguments[_key];var _this=
_super.call.apply(_super,[this].concat(_args));_defineProperty(_assertThisInitialized(_this),"mounted",!1);_defineProperty(_assertThisInitialized(_this),"isReady",!1);_defineProperty(_assertThisInitialized(_this),"isPlaying",!1);_defineProperty(_assertThisInitialized(_this),"isLoading",!0);_defineProperty(_assertThisInitialized(_this),"loadOnReady",null);_defineProperty(_assertThisInitialized(_this),"startOnPlay",!0);_defineProperty(_assertThisInitialized(_this),"seekOnPlay",null);_defineProperty(_assertThisInitialized(_this),
"onDurationCalled",!1);_defineProperty(_assertThisInitialized(_this),"getInternalPlayer",function(key){return _this.player?_this.player[key]:null});_defineProperty(_assertThisInitialized(_this),"progress",function(){if(_this.props.url&&_this.player&&_this.isReady){var playedSeconds=_this.getCurrentTime()||0,loadedSeconds=_this.getSecondsLoaded(),duration=_this.getDuration();if(duration){playedSeconds={playedSeconds:playedSeconds,played:playedSeconds/duration};null!==loadedSeconds&&(playedSeconds.loadedSeconds=
loadedSeconds,playedSeconds.loaded=loadedSeconds/duration);if(playedSeconds.playedSeconds!==_this.prevPlayed||playedSeconds.loadedSeconds!==_this.prevLoaded)_this.props.onProgress(playedSeconds);_this.prevPlayed=playedSeconds.playedSeconds;_this.prevLoaded=playedSeconds.loadedSeconds}}_this.progressTimeout=setTimeout(_this.progress,_this.props.progressFrequency||_this.props.progressInterval)});_defineProperty(_assertThisInitialized(_this),"handleReady",function(){if(_this.mounted){_this.isReady=!0;
_this.isLoading=!1;var _this$props=_this.props,onReady=_this$props.onReady,playing=_this$props.playing,volume=_this$props.volume;_this$props=_this$props.muted;onReady();_this$props||null===volume||_this.player.setVolume(volume);_this.loadOnReady?(_this.player.load(_this.loadOnReady,!0),_this.loadOnReady=null):playing&&_this.player.play();_this.handleDurationCheck()}});_defineProperty(_assertThisInitialized(_this),"handlePlay",function(){_this.isPlaying=!0;_this.isLoading=!1;var _this$props2=_this.props,
onStart=_this$props2.onStart,onPlay=_this$props2.onPlay;_this$props2=_this$props2.playbackRate;_this.startOnPlay&&(_this.player.setPlaybackRate&&1!==_this$props2&&_this.player.setPlaybackRate(_this$props2),onStart(),_this.startOnPlay=!1);onPlay();_this.seekOnPlay&&(_this.seekTo(_this.seekOnPlay),_this.seekOnPlay=null);_this.handleDurationCheck()});_defineProperty(_assertThisInitialized(_this),"handlePause",function(e){_this.isPlaying=!1;if(!_this.isLoading)_this.props.onPause(e)});_defineProperty(_assertThisInitialized(_this),
"handleEnded",function(){var _this$props3=_this.props,loop=_this$props3.loop,onEnded=_this$props3.onEnded;_this$props3.activePlayer.loopOnEnded&&loop&&_this.seekTo(0);loop||(_this.isPlaying=!1,onEnded())});_defineProperty(_assertThisInitialized(_this),"handleError",function(){var _this$props4;_this.isLoading=!1;(_this$props4=_this.props).onError.apply(_this$props4,arguments)});_defineProperty(_assertThisInitialized(_this),"handleDurationCheck",function(){clearTimeout(_this.durationCheckTimeout);var duration=
_this.getDuration();duration?_this.onDurationCalled||(_this.props.onDuration(duration),_this.onDurationCalled=!0):_this.durationCheckTimeout=setTimeout(_this.handleDurationCheck,100)});_defineProperty(_assertThisInitialized(_this),"handleLoaded",function(){_this.isLoading=!1});_defineProperty(_assertThisInitialized(_this),"ref",function(player){player&&(_this.player=player)});return _this}_inherits(Player$jscomp$0,_Component);var _super=_createSuper(Player$jscomp$0);_createClass(Player$jscomp$0,[{key:"componentDidMount",
value:function(){this.mounted=!0;this.player.load(this.props.url);this.progress()}},{key:"componentWillUnmount",value:function(){clearTimeout(this.progressTimeout);clearTimeout(this.durationCheckTimeout);this.isReady&&this.player.stop();this.player.disablePIP&&this.player.disablePIP();this.mounted=!1}},{key:"componentDidUpdate",value:function(prevProps){var _this2=this,_this$props5=this.props,url=_this$props5.url,playing=_this$props5.playing,volume=_this$props5.volume,muted=_this$props5.muted,playbackRate=
_this$props5.playbackRate,pip=_this$props5.pip,loop=_this$props5.loop;_this$props5=_this$props5.activePlayer;if(!(0,_utils.isEqual)(prevProps.url,url)){if(this.isLoading&&!_this$props5.forceLoad){console.warn("ReactPlayer: the attempt to load ".concat(url," is being deferred until the player has loaded"));this.loadOnReady=url;return}this.startOnPlay=this.isLoading=!0;this.onDurationCalled=!1;this.player.load(url,this.isReady)}prevProps.playing||!playing||this.isPlaying||this.player.play();prevProps.playing&&
!playing&&this.isPlaying&&this.player.pause();!prevProps.pip&&pip&&this.player.enablePIP&&this.player.enablePIP();prevProps.pip&&!pip&&this.player.disablePIP&&this.player.disablePIP();prevProps.volume!==volume&&null!==volume&&this.player.setVolume(volume);prevProps.muted!==muted&&(muted?this.player.mute():(this.player.unmute(),null!==volume&&setTimeout(function(){return _this2.player.setVolume(volume)})));prevProps.playbackRate!==playbackRate&&this.player.setPlaybackRate&&this.player.setPlaybackRate(playbackRate);
prevProps.loop!==loop&&this.player.setLoop&&this.player.setLoop(loop)}},{key:"getDuration",value:function(){return this.isReady?this.player.getDuration():null}},{key:"getCurrentTime",value:function(){return this.isReady?this.player.getCurrentTime():null}},{key:"getSecondsLoaded",value:function(){return this.isReady?this.player.getSecondsLoaded():null}},{key:"seekTo",value:function(amount,type){var _this3=this;this.isReady||0===amount?(type?"fraction"===type:0<amount&&1>amount)?(type=this.player.getDuration())?
this.player.seekTo(type*amount):console.warn("ReactPlayer: could not seek using fraction – duration not yet available"):this.player.seekTo(amount):(this.seekOnPlay=amount,setTimeout(function(){_this3.seekOnPlay=null},5E3))}},{key:"render",value:function(){var Player=this.props.activePlayer;return Player?_react["default"].createElement(Player,_extends({},this.props,{ref:this.ref,onReady:this.handleReady,onPlay:this.handlePlay,onPause:this.handlePause,onEnded:this.handleEnded,onLoaded:this.handleLoaded,
onError:this.handleError})):null}}]);return Player$jscomp$0}(_react.Component);exports["default"]=require;_defineProperty(require,"displayName","Player");_defineProperty(require,"propTypes",global.propTypes);_defineProperty(require,"defaultProps",global.defaultProps)}
//# sourceMappingURL=module$node_modules$react_player$lib$Player.js.map
